@@ -1,7 +1,6 @@
 package Audio::Nama::Assign;
-use Modern::Perl;
+use Modern::Perl '2020';
 our $VERSION = 1.0;
-use 5.008;
 use feature 'state';
 use strict;
 use warnings;
