@@ -9,7 +9,7 @@
 
 package Audio::Nama;
 
-use Modern::Perl;
+use Modern::Perl '2020';
 no warnings 'uninitialized';
 
 use Audio::Nama::Globals qw(:all);
