@@ -1,7 +1,8 @@
 # ----------- Ecasound cleanup (post-recording) -----------
 package Audio::Nama::EcasoundCleanup;
 use Role::Tiny;
-use Modern::Perl;
+use Modern::Perl '2020';
+our $VERSION = 1.0;
 sub cleanup {
 	my $self = shift;
 	Audio::Nama::rec_cleanup();
@@ -9,7 +10,7 @@ sub cleanup {
 
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 use Cwd;
 use File::Spec::Functions qw(splitpath);
 use Audio::Nama::Globals qw(:all);
