@@ -1,7 +1,7 @@
 ## -------------- Effects registry ---------------
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 use Audio::Nama::Util qw(round);
 no warnings 'uninitialized';
 
