@@ -2,7 +2,7 @@
 
 package Audio::Nama;
 use Audio::Nama::Effect  qw(:all);
-use Modern::Perl;
+use Modern::Perl '2020';
 
 sub setup_grammar {
 
