@@ -1,7 +1,7 @@
 # -------------------- Help ----------------------
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 
 {
 no warnings 'uninitialized';
