@@ -1,7 +1,7 @@
 # ----------- Latency Compensation -----------
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 no warnings 'uninitialized';
 use Audio::Nama::Globals qw(:all);
 use Storable qw(dclone);
