@@ -1,7 +1,7 @@
 # ------------- MIDI routines -----------
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 #use Audio::Nama::Log qw(logpkg);
 use Carp;
 
