@@ -1,7 +1,7 @@
 # ----------- Modes: mastering, preview, doodle ---------
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 {
 sub set_preview_mode {
 
