@@ -2,7 +2,8 @@
 # support for beats and bars
 
 package Audio::Nama::Tempo;
-use Modern::Perl;
+use Modern::Perl '2020';
+our $VERSION = 1.0;
 use Audio::Nama::Globals qw($config);
 use Audio::Nama::Object qw( label bars meter tempo ticks);
 use List::Util qw(sum);
@@ -247,7 +248,7 @@ sub notation_to_time {
 }
 
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 use Data::Dumper::Concise;
 use Audio::Nama::Log qw(logsub logpkg);
 use Audio::Nama::Util qw(strip_comments);
