@@ -1,7 +1,8 @@
 {
 package Audio::Nama::TrackRegion;
 use Role::Tiny;
-use Modern::Perl;
+use Modern::Perl '2020';
+our $VERSION = 1.0;
 use Audio::Nama::Globals qw(:all);
 use Carp;
 
